==> opennms_21.0.3-1.tar.gz: opennms-source/features/telemetry/listeners/api/src/main/java/org/opennms/netmgt/telemetry/listeners/api/TelemetryMessage.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2017-2017 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2017 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.telemetry.listeners.api;

import org.opennms.core.ipc.sink.api.Message;
import org.opennms.core.utils.LocationUtils;

import java.net.DatagramPacket;
import java.net.InetSocketAddress;
import java.nio.ByteBuffer;
import java.util.Arrays;

public class TelemetryMessage implements Message {
    private final InetSocketAddress source;
    private final ByteBuffer buffer;

    public TelemetryMessage(InetSocketAddress source, ByteBuffer buffer) {
        this.source = source;
        this.buffer = buffer;
    }

    public InetSocketAddress getSource() {
        return source;
    }

    public ByteBuffer getBuffer() {
        return buffer;
    }
}

==> opennms_22.0.3-1.tar.gz: opennms-source/features/telemetry/listeners/api/src/main/java/org/opennms/netmgt/telemetry/listeners/api/TelemetryMessage.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2017-2017 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2017 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.telemetry.listeners.api;

import org.opennms.core.ipc.sink.api.Message;
import java.net.InetSocketAddress;
import java.nio.ByteBuffer;
import java.util.Date;

public class TelemetryMessage implements Message {
    private final InetSocketAddress source;
    private final ByteBuffer buffer;
    private final Date receivedAt;

    public TelemetryMessage(InetSocketAddress source, ByteBuffer buffer) {
        this(source, buffer, new Date());
    }

    public TelemetryMessage(InetSocketAddress source, ByteBuffer buffer, Date receivedAt) {
        this.source = source;
        this.buffer = buffer;
        this.receivedAt = receivedAt;
    }

    public InetSocketAddress getSource() {
        return source;
    }

    public ByteBuffer getBuffer() {
        return buffer;
    }

    public Date getReceivedAt() {
        return receivedAt;
    }
}
